@@ -1,7 +1,7 @@
-# build file to generate the distribution binary tarball
-autoreconf
+#!/bin/sh
+
+clear
 
-# build windows installation file
 ./configure \
   $PKGCFG \
   --host=i686-w64-mingw32.static \
@@ -10,9 +10,11 @@ autoreconf
   --enable-static \
   PTW32_LIBS="-lpthread -lpcreposix -lpcre -lwinmm" \
   FLTK_CONFIG=$PREFIX/i686-w64-mingw32.static/bin/fltk-config \
-  CXXFLAGS+="-std=c++11 -std=gnu++11"
+  CXXFLAGS="-std=c++11 -std=gnu++11" 
+
+make clean
+make -j 6
 
-make -j 8
 $PREFIX/bin/i686-w64-mingw32.static-strip src/flrig.exe
 make nsisinst
 mv src/*setup*exe .
@@ -21,5 +23,8 @@ make clean
 
 # build the distribution tarball
 ./configure
+
 make distcheck
 make clean
+
+
