@@ -47,7 +47,7 @@ extern std::queue<XCVR_STATE> queB;
 
 void read_K3_vfo()
 {
-	unsigned long int freq;
+	unsigned long long freq;
 	freq = selrig->get_vfoA();
 	if (freq != vfoA.freq) {
 		vfoA.freq = freq;
@@ -77,19 +77,19 @@ void read_K3_mode()
 	}
 }
 
-void read_K3_bw()
-{
-	int nu_BW;
-	nu_BW = selrig->get_bwA();
-	if (nu_BW != vfoA.iBW) {
-		vfoA.iBW = vfo->iBW = nu_BW;
-		Fl::awake(setBWControl);
-	}
-	nu_BW = selrig->get_bwB();
-	if (nu_BW != vfoB.iBW) {
-		vfoB.iBW = nu_BW;
-	}
-}
+//void read_K3_bw()
+//{
+//	int nu_BW;
+//	nu_BW = selrig->get_bwA();
+//	if (nu_BW != vfoA.iBW) {
+//		vfoA.iBW = vfo->iBW = nu_BW;
+//		Fl::awake(setBWControl);
+//	}
+//	nu_BW = selrig->get_bwB();
+//	if (nu_BW != vfoB.iBW) {
+//		vfoB.iBW = nu_BW;
+//	}
+//}
 
 
 void K3_set_split(int val)
@@ -106,7 +106,6 @@ void K3_A2B()
 	selrig->set_bwB(vfoB.iBW);
 	selrig->set_modeB(vfoB.imode);
 	FreqDispB->value(vfoB.freq);
-	Fl::focus(FreqDispA);
 }
 
 void cb_K3_swapAB()
@@ -131,5 +130,4 @@ void cb_K3_swapAB()
 	FreqDispA->value(vfoA.freq);
 
 	vfo = &vfoA;
-	Fl::focus(FreqDispA);
 }
