@@ -265,8 +265,8 @@ Fl_ComboBox *opBW = (Fl_ComboBox *)0;
 Fl_ComboBox *opDSP_lo = (Fl_ComboBox *)0;
 Fl_ComboBox *opCENTER = (Fl_ComboBox *)0;
 
-Fl_Counter *opBW_A = (Fl_Counter *)0;
-Fl_Counter *opBW_B = (Fl_Counter *)0;
+Fl_ComboBox *opBW_A = (Fl_ComboBox *)0; //(Fl_Counter *)0;
+Fl_ComboBox *opBW_B = (Fl_ComboBox *)0; //(Fl_Counter *)0;
 
 Fl_Counter *opFilterInner = (Fl_Counter *)0;
 Fl_Counter *opFilterOuter = (Fl_Counter *)0;
@@ -574,6 +574,10 @@ static void cb_mnuSERVER(Fl_Menu_*, void*) {
 	open_server_tab();
 }
 
+static void cb_mnuCLIENT(Fl_Menu_*, void*) {
+	open_client_tab();
+}
+
 static void cb_mnuOnLineHelp(Fl_Menu_*, void*) {
 	visit_URL((void *)("http://www.w1hkj.com/flrig-help/index.html"));
 }
