@@ -37,6 +37,7 @@ Fl_Menu_Item menu_wide_menu[] = {
  {_("AUX"), 0, (Fl_Callback*)cb_mnuOTHER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("TMATE-2"), 0, (Fl_Callback*)cb_mnuTMATE2, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Server"), 0, (Fl_Callback*)cb_mnuSERVER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Client"), 0, (Fl_Callback*)cb_mnuCLIENT, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Polling"), 0, (Fl_Callback*)cb_Polling, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Commands"), 0, (Fl_Callback*)cb_mnuCommands, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Send command"), 0, (Fl_Callback*)cb_Send, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
@@ -424,22 +425,16 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				opFilterOuter->tooltip("Outer cutoff");
 				opFilterOuter->hide();
 
-				opBW_A = new Fl_Counter(xpos + 20, ypos, w1a - 20, 20, _("BW vfoA"));
-				opBW_A->minimum(50);
-				opBW_A->maximum(4000);
-				opBW_A->step(10);
-				opBW_A->lstep(100);
+				opBW_A = new Fl_ComboBox(xpos + 20, ypos, w1a - 20, 20, _("BW vfoA"));
 				opBW_A->align(Fl_Align(FL_ALIGN_LEFT));
 				opBW_A->tooltip("BW vfoA");
+				opBW_A->end();
 				opBW_A->hide();
 
-				opBW_B = new Fl_Counter(xpos + 20, ypos, w1a - 20, 20, _("BW vfoB"));
-				opBW_B->minimum(50);
-				opBW_B->maximum(4000);
-				opBW_B->step(10);
-				opBW_B->lstep(100);
+				opBW_B = new Fl_ComboBox(xpos + 20, ypos, w1a - 20, 20, _("BW vfoB"));
 				opBW_B->align(Fl_Align(FL_ALIGN_LEFT));
 				opBW_B->tooltip("BW vfoB");
+				opBW_B->end();
 				opBW_B->hide();
 
 				opMODE = new Fl_ComboBox(
@@ -482,7 +477,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 						btnAttenuator->labelsize(12);
 						btnAttenuator->callback((Fl_Callback*)cb_btnAttenuator);
 
-						cbo_preamp = new Fl_ComboBox(bx_row1b1a->x() + bx_row1b1a->w(), ypos, 140, 20, "");
+						cbo_preamp = new Fl_ComboBox(bx_row1b1a->x() + bx_row1b1a->w(), ypos, 70, 20, "");
 						cbo_preamp->tooltip(_("Preamp in dB"));
 						cbo_preamp->labelsize(12);
 						cbo_preamp->add("-10 dB|0 dB|10 dB|20 dB|30 dB");
