@@ -22,7 +22,7 @@
 // ---------------------------------------------------------------------
 
 
-#include <config.h>
+#include "config.h"
 
 #include <cstring>
 #include <string>
@@ -47,7 +47,7 @@
 #include "support.h"
 #include "status.h"
 
-//#define CWIO_DEBUG
+#define CWIO_DEBUG
 
 Cserial *cwio_serial = 0;
 Cmorse  *morse = 0;
@@ -61,53 +61,48 @@ int cwio_process = NONE;
 bool cwio_thread_running = false;
 
 static std::string new_text;
-static std::string cwio_text;
-
-
-// return current tick time in seconds
-double cw_now()
-{
-	static struct timeval t1;
-	gettimeofday(&t1, NULL);
-	return t1.tv_sec + t1.tv_usec / 1e6;
-}
+std::string cwio_text;
 
+//======================================================================
 // sub millisecond accurate sleep function
 // sleep_time in seconds
+
+extern double monotonic_seconds();
+
 #ifdef CWIO_DEBUG
 FILE *fcwio = (FILE *)0;
+FILE *fcwio2 = (FILE *)0;
 #endif
 
+static double lasterr = 0;
+
 int cw_sleep (double sleep_time)
 {
-	struct timespec tv;
-	double start_at = cw_now();
+	struct timespec tv1, tv2;
+	double start_at = monotonic_seconds();
 	double end_at = start_at + sleep_time;
-	double delay = sleep_time - 0.005;
-	tv.tv_sec = (time_t) delay;
-	tv.tv_nsec = (long) ((delay - tv.tv_sec) * 1e+9);
-	int rval = 0;
+	double delay = sleep_time - 0.010;
+
+	tv1.tv_sec = (time_t) delay;
+	tv1.tv_nsec = (long) ((delay - tv1.tv_sec) * 1e+9);
+	tv2.tv_sec = 0;
+	tv2.tv_nsec = 10;
+
 #ifdef __WIN32__
 	timeBeginPeriod(1);
-	end_at -= 0.0005;
-#endif
-	while (1) {
-		rval = nanosleep (&tv, &tv);
-		if (rval == 0)
-			break;
-		else if (errno == EINTR)
-			continue;
-		else 
-			return rval;
-	}
-	while (cw_now() < end_at);
-#ifdef __WIN32__
+	nanosleep (&tv1, NULL);
+	while ((lasterr = end_at - monotonic_seconds()) > 0)
+		nanosleep(&tv2, NULL);
 	timeEndPeriod(1);
+#else
+	nanosleep (&tv1, NULL);
+	while (((lasterr = end_at - monotonic_seconds()) > 0))
+		nanosleep(&tv2, NULL);
 #endif
 
 #ifdef CWIO_DEBUG
 	if (fcwio)
-		fprintf(fcwio, "%f\n", cw_now() - start_at - sleep_time);
+		fprintf(fcwio, "%f, %f\n", sleep_time, (end_at - lasterr - start_at));
 #endif
 	return 0;
 }
@@ -133,7 +128,7 @@ void cwio_key(bool state)
 		doPTT(state);
 
 	if (progStatus.cwioKEYLINE == 2) {
-			port->setDTR(progStatus.cwioINVERTED ? !state : state);
+		port->setDTR(progStatus.cwioINVERTED ? !state : state);
 	} else if (progStatus.cwioKEYLINE == 1) {
 		port->setRTS(progStatus.cwioINVERTED ? !state : state);
 	}
@@ -141,17 +136,19 @@ void cwio_key(bool state)
 	return;
 }
 
+double start_at2;
+
 void send_cwkey(char c)
 {
-#ifdef CWIO_DEBUG
-	if (!fcwio) fcwio = fopen("cwio_timing.txt", "a");
-#endif
+	start_at2 = monotonic_seconds();
 
-	static std::string code = "";
-	static double tc = 0;
-	static double tch = 0;
-	static double twd = 0;
-	static double xcvr_corr = 0;
+	std::string code = "";
+	double tc = 0;
+	double tch = 0;
+	double twd = 0;
+	double xcvr_corr = 0;
+	double comp = progStatus.cwio_comp * 1e-3;
+	double requested = 0;
 	Cserial *port = cwio_serial;
 
 	switch (progStatus.cwioSHARED) {
@@ -161,27 +158,24 @@ void send_cwkey(char c)
 		default: port = cwio_serial;
 	}
 
-	if (!port) 
+	if (!port)
 		goto exit_send_cwkey;
 
-	if (!port->IsOpen()) 
+	if (!port->IsOpen())
 		goto exit_send_cwkey;
 
 	tc = 1.2 / progStatus.cwioWPM;
+
+	if (comp < tc) tc -= comp;
 	tch = 3 * tc;
 	twd = 4 * tc;
 
-	if ((progStatus.cwio_comp > 0) && (progStatus.cwio_comp < tc)) {
-		tc = tc - progStatus.cwio_comp;
-		tch = tch - 3 * progStatus.cwio_comp;
-		twd = twd - 4 * progStatus.cwio_comp;
-	}
-
 	xcvr_corr = progStatus.cwio_keycorr * 1e-3;
 	if (xcvr_corr < -tc / 2) xcvr_corr = - tc / 2;
 	else if (xcvr_corr > tc / 2) xcvr_corr = tc / 2;
 
 	if (c == ' ' || c == 0x0a) {
+		requested += twd;
 		cw_sleep(twd);
 		goto exit_send_cwkey;
 	}
@@ -192,27 +186,41 @@ void send_cwkey(char c)
 			goto exit_send_cwkey;
 		}
 		if (progStatus.cwioKEYLINE == 2) {
-			port->setDTR(progStatus.cwioINVERTED ? 0 : 1);
+			cwio_key(progStatus.cwioINVERTED ? 0 : 1);
 		} else if (progStatus.cwioKEYLINE == 1) {
-			port->setRTS(progStatus.cwioINVERTED ? 0 : 1);
+			cwio_key(progStatus.cwioINVERTED ? 0 : 1);
 		}
-		if (code[n] == '.')
-			cw_sleep(tc + xcvr_corr);
-		else
+		if (code[n] == '.') {
+			requested += (tc + xcvr_corr);
+			cw_sleep((tc + xcvr_corr));
+		} else {
+			requested += tch;
 			cw_sleep(tch);
+		}
 
 		if (progStatus.cwioKEYLINE == 2) {
-			port->setDTR(progStatus.cwioINVERTED ? 1 : 0);
+			cwio_key(progStatus.cwioINVERTED ? 1 : 0);
 		} else if (progStatus.cwioKEYLINE == 1) {
-			port->setRTS(progStatus.cwioINVERTED ? 1 : 0);
+			cwio_key(progStatus.cwioINVERTED ? 1 : 0);
 		}
-		if (n == code.length() -1)
+		if (n == code.length() -1) {
+			requested += tch;
 			cw_sleep(tch);
-		else
-			cw_sleep(tc - xcvr_corr);
+		} else {
+			requested += (tc - xcvr_corr);
+			cw_sleep((tc - xcvr_corr));
+		}
 	}
 
 exit_send_cwkey:
+
+#ifdef CWIO_DEBUG
+	if (fcwio2) {
+		double duration = monotonic_seconds() - start_at2;
+		fprintf(fcwio2, "%f, %f, %f\n", duration, requested, duration - requested);
+	}
+#endif
+
 	return;
 }
 
@@ -280,11 +288,12 @@ void sending_text()
 	char c = 0;
 	if (progStatus.cwioPTT) {
 		doPTT(1);
-		cw_sleep(progStatus.cwioPTT / 1000.0);
+		MilliSleep(50);
 	}
 	while (cwio_process == SEND) {
 		c = 0;
-		{	guard_lock lck(&cwio_text_mutex);
+		{
+			guard_lock lck(&cwio_text_mutex);
 			if (!cwio_text.empty()) {
 				c = cwio_text[0];
 				cwio_text.erase(0,1);
@@ -300,16 +309,15 @@ void sending_text()
 		}
 		if (c == ']') {
 			cwio_process = END;
-			cw_sleep(0.005);
 			Fl::awake(terminate_sending);
 			return;
 		}
 		if (c) send_cwkey(c);
-		else cw_sleep(0.005);
+		else MilliSleep(50);
 	}
 	if (progStatus.cwioPTT) {
 		doPTT(0);
-		cw_sleep(progStatus.cwioPTT / 1000.0);
+		MilliSleep(50);
 	}
 }
 
@@ -325,8 +333,8 @@ void do_calibration()
 {
 	std::string paris = "PARIS ";
 	std::string teststr;
-	unsigned long start_time = 0;
-	unsigned long end_time = 0;
+	double start_time = 0;
+	double end_time = 0;
 
 	progStatus.cwio_comp = 0;
 
@@ -335,14 +343,15 @@ void do_calibration()
 
 	txt_to_send->value();
 
-	start_time = zmsec();
+	start_time = monotonic_seconds();
 	for (size_t n = 0; n < teststr.length(); n++) {
 		send_cwkey(teststr[n]);
 	}
 
-	end_time = zmsec();
+	end_time = monotonic_seconds();
+	double corr = 1000.0 * (end_time - start_time - 60.0) / (50.0 * progStatus.cwioWPM);
 
-	progStatus.cwio_comp = 50 * (1.0 - 60000.0 / (end_time - start_time));
+	progStatus.cwio_comp = corr;
 
 	Fl::awake(update_comp_value);
 }
@@ -351,10 +360,83 @@ void do_calibration()
 // cwio thread
 //----------------------------------------------------------------------
 
+extern bool PRIORITY;
+
 void *cwio_loop(void *)
 {
 	cwio_thread_running = true;
 	cwio_process = NONE;
+
+#if 1
+if (PRIORITY) {
+	char estr[200];
+	std::string erfname = RigHomeDir;
+	erfname.append("priority.txt");
+	FILE *erfile = fopen(erfname.c_str(),"w");
+#if 0
+//#ifndef __WIN32__
+	int erc = nice(-10);
+	if (erc == -1)
+		snprintf(estr, sizeof(estr), "%d: errno: %d, %s", __LINE__, errno, strerror(errno));
+	else
+		snprintf(estr, sizeof(estr), "%d: set thread priority to %d", __LINE__, erc);
+	fprintf(erfile, "%s\n", estr);
+
+#else
+
+	// bump up the cwio thread priority
+	pthread_attr_t tattr;
+	if (pthread_attr_init(&tattr)) {
+		LOG_ERROR("cwio thread fail (pthread_attr_init)");
+		snprintf(estr, sizeof(estr), "%d: errno: %d, %s", __LINE__, errno, strerror(errno));
+		fprintf(erfile, "%s\n", estr);
+	}
+	sched_param param;
+	int sched;
+	if (pthread_attr_getinheritsched(&tattr, &sched)) {
+		LOG_ERROR("cwio thread fail (pthread_attr_getinheritsched)");
+		snprintf(estr, sizeof(estr), "%d: errno: %d, %s", __LINE__, errno, strerror(errno));
+		fprintf(erfile, "%s\n", estr);
+	}
+	sched = PTHREAD_EXPLICIT_SCHED;
+	if (pthread_attr_setinheritsched(&tattr, sched)) {
+		LOG_ERROR("cwio thread fail (pthread_attr_setinheritsched)");
+		snprintf(estr, sizeof(estr), "%d: errno: %d, %s", __LINE__, errno, strerror(errno));
+		fprintf(erfile, "%s\n", estr);
+	}
+	if (pthread_attr_getschedparam(&tattr, &param)) {
+		LOG_ERROR("cwio thread fail (pthread_attr_getscheduparam)");
+		snprintf(estr, sizeof(estr), "%d: errno: %d, %s", __LINE__, errno, strerror(errno));
+		fprintf(erfile, "%s\n", estr);
+	}
+
+	snprintf(estr, sizeof(estr), "%d: priority old = %d", __LINE__, param.sched_priority);
+	fprintf(erfile, "%s\n", estr);
+
+	param.sched_priority = sched_get_priority_max(SCHED_FIFO);
+	snprintf(estr, sizeof(estr), "%d: priority new = %d", __LINE__, param.sched_priority);
+	fprintf(erfile, "%s\n", estr);
+
+	if (pthread_attr_setschedparam(&tattr, &param)) {
+		LOG_ERROR("cwio thread fail (pthread_attr_setscheduparam)");
+		snprintf(estr, sizeof(estr), "%d: errno: %d, %s", __LINE__, errno, strerror(errno));
+		fprintf(erfile, "%s\n", estr);
+	}
+
+	if (pthread_attr_getschedparam(&tattr, &param)) {
+		LOG_ERROR("cwio thread fail (pthread_attr_getscheduparam)");
+		snprintf(estr, sizeof(estr), "%d: errno: %d, %s", __LINE__, errno, strerror(errno));
+		fprintf(erfile, "%s\n", estr);
+	}
+
+	snprintf(estr, sizeof(estr), "%d: priority set to %d", __LINE__, param.sched_priority);
+	fprintf(erfile, "%s\n", estr);
+#endif
+	fclose(erfile);
+} // PRIORITY
+
+#endif
+
 	while (1) {
 		pthread_mutex_lock(&cwio_mutex);
 		pthread_cond_wait(&cwio_cond, &cwio_mutex);
@@ -383,6 +465,20 @@ int start_cwio_thread()
 	memset((void *) &cwio_mutex,   0, sizeof(cwio_mutex));
 	memset((void *) &cwio_cond,    0, sizeof(cwio_cond));
 
+#ifdef CWIO_DEBUG
+	if (!fcwio) {
+		std::string debug_fname;
+		debug_fname.assign(RigHomeDir).append("cwio_timing.txt");
+		fcwio = fopen(debug_fname.c_str(), "a");
+	}
+
+	if (!fcwio2) {
+		std::string debug_fname2;
+		debug_fname2.assign(RigHomeDir).append("cwio_bits.txt");
+		fcwio2 = fopen(debug_fname2.c_str(), "a");
+	}
+#endif
+
 	if(pthread_cond_init(&cwio_cond, NULL)) {
 		LOG_ERROR("cwio thread create fail (pthread_cond_init)");
 		return 1;
@@ -393,15 +489,53 @@ int start_cwio_thread()
 		return 1;
 	}
 
+#if 0
+	// bump up the cwio thread priority
+	pthread_attr_t tattr;
+	if (pthread_attr_init(&tattr)) {
+		LOG_ERROR("cwio thread fail (pthread_attr_init)");
+		std::cout << __LINE__ << " : " << errno << ", " << strerror(errno) << std::endl;
+	}
+	sched_param param;
+	int sched;
+	if (pthread_attr_getinheritsched(&tattr, &sched)) {
+		LOG_ERROR("cwio thread fail (pthread_attr_getinheritsched)");
+		std::cout << __LINE__ << " : errno " << errno << ", " << strerror(errno) << std::endl;
+	}
+	sched = PTHREAD_EXPLICIT_SCHED;
+	if (pthread_attr_setinheritsched(&tattr, sched)) {
+		LOG_ERROR("cwio thread fail (pthread_attr_setinheritsched)");
+		std::cout << __LINE__ << " : errno " << errno << ", " << strerror(errno) << std::endl;
+	}
+	if (pthread_attr_getschedparam(&tattr, &param)) {
+		LOG_ERROR("cwio thread fail (pthread_attr_getscheduparam)");
+		std::cout << __LINE__ << " : errno " << errno << ", " << strerror(errno) << std::endl;
+	}
+		std::cout << __LINE__ << " : priority old = " << param.sched_priority << std::endl;
+	param.sched_priority = sched_get_priority_max(SCHED_FIFO);
+		std::cout << __LINE__ << " : priority new = " << param.sched_priority << std::endl;
+	if (pthread_attr_setschedparam(&tattr, &param)) {
+		LOG_ERROR("cwio thread fail (pthread_attr_setscheduparam)");
+		std::cout << __LINE__ << " : errno " << errno << ", " << strerror(errno) << std::endl;
+	}
+	if (pthread_attr_getschedparam(&tattr, &param)) {
+		LOG_ERROR("cwio thread fail (pthread_attr_getscheduparam)");
+		std::cout << __LINE__ << " : errno " << errno << ", " << strerror(errno) << std::endl;
+	}
+	std::cout << __LINE__ << " : priority got = " << param.sched_priority << std::endl;
+#endif
+
 	if (pthread_create(&cwio_pthread, NULL, cwio_loop, NULL) < 0) {
 		pthread_mutex_destroy(&cwio_mutex);
 		LOG_ERROR("cwio thread create fail (pthread_create)");
+		std::cout << __LINE__ << " : errno " << errno << ", " << strerror(errno) << std::endl;
 		return 1;
 	}
 
 	LOG_INFO("started cwio thread");
 
-	cw_sleep(0.010); // Give the CPU time to set 'cwio_thread_running'
+
+	MilliSleep(50); // Give the CPU time to set 'cwio_thread_running'
 	return 0;
 }
 
@@ -433,6 +567,17 @@ void stop_cwio_thread()
 
 	close_cwkey();
 
+#ifdef CWIO_DEBUG
+	if (fcwio) {
+		fclose(fcwio);
+		fcwio = 0;
+	}
+	if (fcwio2) {
+		fclose(fcwio2);
+		fcwio2 = 0;
+	}
+#endif
+
 	if (cwio_serial) {
 		delete cwio_serial;
 		cwio_serial = 0;
@@ -465,11 +610,11 @@ void add_cwio(std::string txt)
 	if (cw_log_nbr) {
 		while ((p = txt.find("~#")) != std::string::npos) {
 			char sznum[10];
-			if (cwlog_menu_leading_zeros->value())
-				snprintf(sznum, sizeof(sznum), "%0d", progStatus.cw_log_nbr);
+			if (progStatus.cw_log_leading_zeros)
+				snprintf(sznum, sizeof(sznum), "%04d", progStatus.cw_log_nbr);
 			else
 				snprintf(sznum, sizeof(sznum), "%d", progStatus.cw_log_nbr);
-			if (cwlog_menu_cut_numbers->value()) {
+			if (progStatus.cw_log_cut_numbers) {
 				for (size_t i = 1; i < strlen(sznum); i++) {
 					if (sznum[i] == '0') sznum[i] = 'T';
 					if (sznum[i] == '9') sznum[i] = 'N';
