@@ -114,7 +114,7 @@ public:
 	void set_auto_notch(int v);
 	int  get_auto_notch();
 
-	const char **bwtable(int);
+	std::vector<std::string>& bwtable(int);
 
 	const char * get_bwname_(int bw, int md);
 
