@@ -2,14 +2,14 @@
 // Copyright (C) 2014
 //              David Freese, W1HKJ
 //
-// This file is part of flrig.
+// This file is part of fldigi
 //
-// flrig is free software; you can redistribute it and/or modify
+// fldigi is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
-// flrig is distributed in the hope that it will be useful,
+// fldigi is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
@@ -23,11 +23,27 @@
 
 #include <FL/Fl_Input.H>
 
+#include "config.h"
+
 class Fl_Input2 : public Fl_Input
 {
+private:
+	int 	ascii_cnt; // restart the numeric keypad entries.
+	int		ascii_chr; // character value of ASCII > 0x80
+	int		handle_key_ascii(int key);
+	char	*utf8text;
+	int		utf8cnt;
+
 public:
 	Fl_Input2(int x, int y, int w, int h, const char* l = 0);
 	int handle(int event);
+
+#if FLRIG_FLTK_API_MINOR > 3
+	int position() { return Fl_Input::insert_position(); }
+	int position(int p, int m) { return Fl_Input::insert_position(p, m); }
+	int position(int p) { return Fl_Input::insert_position(p, p); }
+#endif
+
 };
 
 #endif // FL_INPUT2_
