@@ -122,7 +122,7 @@ public:
 
 	void set_cw_vol();
 
-	const char **bwtable(int m);
+	std::vector<std::string>& bwtable(int m);
 
 	void set_PTT_control(int val);
 	int  get_PTT();
