@@ -93,7 +93,7 @@ public:
 	const char *FILT(int &val);
 	const char *nextFILT();
 
-	const char **bwtable(int m);
+	std::vector<std::string>& bwtable(int m);
 
 	void set_band_selection(int v);
 	void get_band_selection(int v);
