@@ -120,9 +120,9 @@ enum TS590MODES { LSB, USB, CW, FM, AM, FSK, CWR, FSKR, LSBD, USBD, FMD };
 
 //	bool sendTScommand(std::string, int, bool);
 
-	const char **bwtable(int);
-	const char **lotable(int);
-	const char **hitable(int);
+	std::vector<std::string>& bwtable(int);
+	std::vector<std::string>& lotable(int);
+	std::vector<std::string>& hitable(int);
 
 	const char * get_bwname_(int bw, int md);
 
