@@ -114,8 +114,8 @@ extern Fl_Group *grp_row1a;
 
 extern Fl_ComboBox *opCENTER;
 extern Fl_ComboBox *opBW;
-extern Fl_Counter *opBW_A;
-extern Fl_Counter *opBW_B;
+extern Fl_ComboBox *opBW_A;
+extern Fl_ComboBox *opBW_B;
 
 extern Fl_Button *btnDSP;
 extern Fl_ComboBox *opDSP_lo;
@@ -417,9 +417,9 @@ extern Fl_Box *tcpip_menu_box;
 extern Fl_Group *tcpip_box;
 extern Fl_Check_Button *chk_use_tcpip;
 
-extern Fl_Radio_Light_Button *btn_wide_ui;
-extern Fl_Radio_Light_Button *btn_narrow_ui;
-extern Fl_Radio_Light_Button *btn_touch_ui;
+extern Fl_Check_Button *btn_wide_ui;
+extern Fl_Check_Button *btn_narrow_ui;
+extern Fl_Check_Button *btn_touch_ui;
 extern Fl_Check_Button *chk_sliders_button;
 
 extern Fl_Box *lblTest;
