@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _TT588_H
@@ -42,10 +42,10 @@ public:
 
 	bool check();
 
-	unsigned long int get_vfoA();
-	void set_vfoA(unsigned long int);
-	unsigned long int get_vfoB();
-	void set_vfoB(unsigned long int);
+	unsigned long long get_vfoA();
+	void set_vfoA(unsigned long long);
+	unsigned long long get_vfoB();
+	void set_vfoB(unsigned long long);
 	void setVfoAdj(double v);
 
 	void set_modeA(int val);
@@ -70,6 +70,9 @@ public:
 	void set_attenuator(int val);
 	int  get_attenuator();
 
+//	const char * PRE_label();
+	const char * ATT_label();
+
 	void set_rf_gain(int val);
 	int  get_rf_gain();
 	void set_if_shift(int val);
