@@ -22,7 +22,7 @@
 #ifndef TIMEOPS_H_
 #define TIMEOPS_H_
 
-#include <config.h>
+#include "config.h"
 #include <time.h>
 #include <sys/time.h>
 
