@@ -50,7 +50,9 @@ static int mode_filterB[NUM_MODES] = {1,1,1,1,1,1,1,1,1,1,1,1,1,1};
 static int mode_bwA[NUM_MODES] = {-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1};
 static int mode_bwB[NUM_MODES] = {-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1};
 
-static const char *szfilter[NUM_FILTERS] = {"1", "2", "3"};
+static std::vector<std::string>szfilter;
+static const char *vszfilter[] =
+{"1", "2", "3"};
 
 enum {
 	LSB7100, USB7100, AM7100, CW7100, RTTY7100,
@@ -59,11 +61,13 @@ enum {
 
 static const char mdval[] = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 17, 0, 1, 2, 5};
 
-const char *IC7100modes_[] = {
+static std::vector<std::string>IC7100modes_;
+static const char *vIC7100modes_[] =
+{
 "LSB",    "USB",    "AM",   "CW", 
 "RTTY",   "FM",    "WFM",   "CW-R",
 "RTTY-R", "DV",  "LSB-D",  "USB-D",
-"AM-D",   "FM-D", NULL};
+"AM-D",   "FM-D"};
 
 static char IC7100_mode_type[] = {
 'L',      'U',      'U',      'L',
@@ -88,13 +92,14 @@ const char IC7100_mode_nbr[] = {
 	0x05  // FM-D
 };
 
-const char *IC7100_ssb_bws[] = {
+static std::vector<std::string>IC7100_ssb_bws;
+static const char *vIC7100_ssb_bws[] =
+{
 "50",    "100",  "150",  "200",  "250",  "300",  "350",  "400",  "450",  "500",
 "600",   "700",  "800",  "900", "1000", "1100", "1200", "1300", "1400", "1500",
 "1600", "1700", "1800", "1900", "2000", "2100", "2200", "2300", "2400", "2500",
 "2600", "2700", "2800", "2900", "3000", "3100", "3200", "3300", "3400", "3500",
-"3600",
-NULL };
+"3600"};
 static int IC7100_vals_ssb_bws[] = {
  1, 2, 3, 4, 5, 6, 7, 8, 9,10,
 11,12,13,14,15,16,17,18,19,20,
@@ -102,13 +107,14 @@ static int IC7100_vals_ssb_bws[] = {
 31,32,33,34,35,36,37,38,39,40,
 41, WVALS_LIMIT};
 
-const char *IC7100_am_bws[] = {
+static std::vector<std::string>IC7100_am_bws;
+static const char *vIC7100_am_bws[] =
+{
 "200",   "400",  "600",  "800", "1000", "1200", "1400", "1600", "1800", "2000",
 "2200", "2400", "2600", "2800", "3000", "3200", "3400", "3600", "3800", "4000",
 "4200", "4400", "4600", "4800", "5000", "5200", "5400", "5600", "5800", "6000",
 "6200", "6400", "6600", "6800", "7000", "7100", "7400", "7100", "7800", "8000",
-"8200", "8400", "8600", "8800", "9000", "9200", "9400", "9600", "9800", "10000", 
-NULL };
+"8200", "8400", "8600", "8800", "9000", "9200", "9400", "9600", "9800", "10000"};
 static int IC7100_bw_vals_AM[] = {
  1, 2, 3, 4, 5, 6, 7, 8, 9,10,
 11,12,13,14,15,16,17,18,19,20,
@@ -117,19 +123,23 @@ static int IC7100_bw_vals_AM[] = {
 41,42,43,44,45,46,47,48,49,50,
  WVALS_LIMIT};
 
-const char *IC7100_rtty_bws[] = {
+static std::vector<std::string>IC7100_rtty_bws;
+static const char *vIC7100_rtty_bws[] =
+{
 "50",    "100",  "150",  "200",  "250",  "300",  "350",  "400",  "450",  "500",
 "600",   "700",  "800",  "900", "1000", "1100", "1200", "1300", "1400", "1500",
 "1600", "1700", "1800", "1900", "2000", "2100", "2200", "2300", "2400", "2500",
-"2600", "2700",
-NULL };
+"2600", "2700"};
 static int IC7100_bw_vals_RTTY[] = {
  1, 2, 3, 4, 5, 6, 7, 8, 9,10,
 11,12,13,14,15,16,17,18,19,20,
 21,22,23,24,25,26,27,28,29,30,
 31,32, WVALS_LIMIT};
 
-const char *IC7100_fixed_bws[] = { "FIXED", NULL };
+static std::vector<std::string>IC7100_fixed_bws;
+static const char *vIC7100_fixed_bws[] =
+{ "FIXED" };
+
 static int IC7100_fixed_bw_vals[] = { 1, WVALS_LIMIT};
 
 static GUI IC7100_widgets[]= {
@@ -153,6 +163,18 @@ static GUI IC7100_widgets[]= {
 
 void RIG_IC7100::initialize()
 {
+	VECTOR (szfilter, vszfilter);
+	VECTOR (IC7100modes_, vIC7100modes_);
+	VECTOR (IC7100_ssb_bws, vIC7100_ssb_bws);
+	VECTOR (IC7100_am_bws, vIC7100_am_bws);
+	VECTOR (IC7100_rtty_bws, vIC7100_rtty_bws);
+	VECTOR (IC7100_fixed_bws, vIC7100_fixed_bws);
+
+	modes_ = IC7100modes_;
+	bandwidths_ = IC7100_ssb_bws;
+	bw_vals_ = IC7100_vals_ssb_bws;
+	_mode_type = IC7100_mode_type;
+
 	IC7100_widgets[0].W = btnVol;
 	IC7100_widgets[1].W = sldrVOLUME;
 	IC7100_widgets[2].W = btnAGC;
@@ -632,7 +654,7 @@ int RIG_IC7100::get_modeA()
 	if (A.filter > 0 && A.filter < 4)
 		mode_filterA[A.imode] = A.filter;
 
-	get_trace(4, "mode_filterA[", IC7100modes_[md], "] = ", szfilter[A.filter-1]);
+	get_trace(4, "mode_filterA[", IC7100modes_[md].c_str(), "] = ", szfilter[A.filter-1].c_str());
 
 	if (A.imode == CW7100 || A.imode == CWR7100) {
 		cmd.assign(pre_to).append("\x1A\x05");
@@ -750,7 +772,7 @@ int RIG_IC7100::get_modeB()
 	if (B.filter > 0 && B.filter < 4)
 		mode_filterA[B.imode] = B.filter;
 
-	get_trace(4, "mode_filterB[", IC7100modes_[md], "] = ", szfilter[A.filter-1]);
+	get_trace(4, "mode_filterB[", IC7100modes_[md].c_str(), "] = ", szfilter[A.filter-1].c_str());
 
 	if (B.imode == CW7100 || B.imode == CWR7100) {
 		cmd.assign(pre_to).append("\x1A\x05");
@@ -910,26 +932,25 @@ int RIG_IC7100::adjust_bandwidth(int m)
 	return 0;
 }
 
-const char ** RIG_IC7100::bwtable(int m)
+std::vector<std::string>& RIG_IC7100::bwtable(int m)
 {
-	const char **table;
 	switch (m) {
 		case AM7100: case AMD7100:
-			table = IC7100_am_bws;
+			return IC7100_am_bws;
 			break;
 		case DV7100:
 		case FM7100: case WFM7100: case FMD7100:
-			table = IC7100_fixed_bws;
+			return IC7100_fixed_bws;
 			break;
 		case RTTY7100: case RTTYR7100:
-			table = IC7100_rtty_bws;
+			return IC7100_rtty_bws;
 			break;
 		case CW7100: case CWR7100:
 		case USB7100: case LSB7100: case USBD7100: case LSBD7100:
 		default:
-			table = IC7100_ssb_bws;
+			return IC7100_ssb_bws;
 	}
-	return table;
+	return IC7100_ssb_bws;
 }
 
 int RIG_IC7100::def_bandwidth(int m)
@@ -2169,7 +2190,7 @@ const char *RIG_IC7100::FILT(int val)
 {
 	if (val < 1) val = 1;
 	if (val > 3) val = 3;
-	return(szfilter[val - 1]);
+	return szfilter[val - 1].c_str();
 }
 
 const char *RIG_IC7100::nextFILT()
@@ -2179,7 +2200,7 @@ const char *RIG_IC7100::nextFILT()
 	val++;
 	if (val > 3) val = 1;
 	set_FILT(val);
-	return szfilter[val - 1];
+	return szfilter[val - 1].c_str();
 }
 
 void RIG_IC7100::set_FILTERS(std::string s)
