@@ -452,6 +452,19 @@ int RIG_FT991::get_smeter()
 	return mtr;
 }
 
+/*
+const static std::vector< std::vector< float > > swr_tbl = {
+    {
+        {  0,  1 }, // 1.0
+        { 10,  3 }, // 1.1
+        { 63, 11 }, // 1.5
+        { 92, 23 }, // 2.0
+        {107, 35 }, // 2.5
+        {116, 48 }, // 3.0
+        {255, 100 }, // infinity
+    }
+};
+
 int RIG_FT991::get_swr()
 {
 	cmd = rsp = "RM6";
@@ -462,7 +475,34 @@ int RIG_FT991::get_swr()
 	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
-	return (int)ceil(mtr / 2.56);
+	//return interpolate(mtr, std::vector<std::vector<float>>swr_tbl);
+	return interpolate(mtr, swr_tbl);
+}
+*/
+
+const static PAIR swr_tbl[] = { // values can be mix of int, float, or double
+	{  0,  1 }, // 1.0
+	{ 10,  3 }, // 1.1
+	{ 63, 11 }, // 1.5
+	{ 92, 23 }, // 2.0
+	{107, 35 }, // 2.5
+	{116, 48 }, // 3.0
+	{255, 100 }, // infinity
+};
+
+int RIG_FT991::get_swr()
+{
+	PAIRS swr_pairs( define_PAIR(swr_tbl) );
+
+	cmd = rsp = "RM6";
+	cmd += ';';
+	wait_char(';',7, FL991_WAIT_TIME, "get swr", ASC);
+
+	size_t p = replystr.rfind(rsp);
+	if (p == std::string::npos) return 0;
+	if (p + 6 >= replystr.length()) return 0;
+	int mtr = atoi(&replystr[p+3]);
+	return swr_pairs.value(mtr);
 }
 
 int RIG_FT991::get_alc()
@@ -480,6 +520,8 @@ int RIG_FT991::get_alc()
 
 double RIG_FT991::get_voltmeter()
 {
+	get_swr();
+
 	cmd = "RM8;";
 	std::string resp = "RM";
 
@@ -1364,17 +1406,41 @@ void RIG_FT991::set_xcvr_auto_on()
 {
 	if (!progStatus.xcvr_auto_on) return;
 
+// This command requires dummy data be initially sent. Then after one
+// second and before two seconds the command is sent.
+
+	cmd = "IF;"; // use as the dummy data
+	sendCommand(cmd);
+	update_progress(0);
+	for (int i = 0; i < 1500; i += 100) {
+		MilliSleep(100);
+		update_progress(100 * i / 6000);
+		Fl::awake();
+	}
+
 	cmd = rsp = "PS";
 	cmd.append(";");
-	wait_char(';', 4, FL991_WAIT_TIME, "Test: Is Rig ON", ASC);
-	size_t p = replystr.rfind(rsp);
-	if (p == std::string::npos) {	// rig is off, power on
-		cmd = "PS1;";
-		sendCommand(cmd);
-		MilliSleep(1100); // 1.0 < T < 2.0 seconds
-		sendCommand(cmd);
-		sendCommand(cmd);
-		MilliSleep(3000);	// Wait for rig startup?  Maybe not needed.
+	get_trace(1, "xcvr ON? ()");
+	wait_char(';',4, 500, "Test: Is Rig ON", ASC);
+	gett("");
+
+	int powerstat;
+	if(sscanf(replystr.c_str(),"PS%d", &powerstat)) {
+		if (powerstat != 0) {
+			update_progress(0);
+			return;
+		}
+	}
+
+	cmd = "PS1;";
+	set_trace(1, "set xcvr ON()");
+	sendCommand(cmd);
+	sett("");
+
+	for (int i = 1500; i < 6000; i += 100) {
+		MilliSleep(100);
+		update_progress(100 * i / 6000);
+		Fl::awake();
 	}
 }
 
