@@ -86,7 +86,7 @@ void clear_combos()
 	select_fskioPORT->add("NONE");
 }
 
-void add_combos(char *port)
+void add_combos(const char *port)
 {
 	if (progStatus.serialtrace) {
 		static char sztr[100];
@@ -102,6 +102,12 @@ void add_combos(char *port)
 
 void set_combo_value()
 {
+	add_combos(progStatus.xcvr_serial_port.c_str());
+	add_combos(progStatus.sep_serial_port.c_str());
+	add_combos(progStatus.aux_serial_port.c_str());
+	add_combos(progStatus.cwioPORT.c_str());
+	add_combos(progStatus.FSK_PORT.c_str());
+
 	selectCommPort->value(progStatus.xcvr_serial_port.c_str());
 	selectAuxPort->value(progStatus.aux_serial_port.c_str());
 	selectSepPTTPort->value(progStatus.sep_serial_port.c_str());
@@ -179,7 +185,7 @@ void init_port_combos()
 			add_combos(gbuf.gl_pathv[j]);
 	}
 	globfree(&gbuf);
-
+#ifndef __FreeBSD__
 	glob("/dev/serial/by-id/*", 0, NULL, &gbuf);
 	for (size_t j = 0; j < gbuf.gl_pathc; j++) {
 		if ( !(stat(gbuf.gl_pathv[j], &st) == 0 && S_ISCHR(st.st_mode)) ||
@@ -189,7 +195,7 @@ void init_port_combos()
 			add_combos(gbuf.gl_pathv[j]);
 	}
 	globfree(&gbuf);
-
+#endif
 	glob("/dev/tty*", 0, NULL, &gbuf);
 	for (size_t j = 0; j < gbuf.gl_pathc; j++) {
 		if ( !(stat(gbuf.gl_pathv[j], &st) == 0 && S_ISCHR(st.st_mode)) ||
@@ -296,9 +302,15 @@ out:
 	}
 
 	const char* tty_fmt[] = {
-		"/dev/ttyS%u",
+#ifndef __FreeBSD__
 		"/dev/ttyUSB%u",
+		"/dev/ttyS%u",
 		"/dev/usb/ttyUSB%u"
+#endif
+#ifdef __FreeBSD__
+		"/dev/cuau%u",
+		"/dev/cuaU%u",
+#endif
 	};
 	LOG_QUIET("%s", "Serial port discovery via 'stat'");
 	for (size_t i = 0; i < sizeof(tty_fmt)/sizeof(*tty_fmt); i++) {
@@ -311,6 +323,7 @@ out:
 			add_combos(ttyname);
 		}
 	}
+
 	set_combo_value();
 }
 #endif // __linux__
