@@ -71,24 +71,6 @@ void TRACED(adjust_small_ui)
 	btnAGC->hide();
 	sldrRFGAIN->redraw_label();
 
-
-	if (!selrig->has_power_out && !selrig->has_voltmeter) {
-		sm_grp1->resize(FreqDispA->x(), sm_grp1->y(), FreqDispA->w(), 40);
-		sm_grp1->color(fl_rgb_color(progStatus.bg_red, progStatus.bg_green, progStatus.bg_blue));
-		grpMeters->resize(sm_grp1->x()+ 2, sm_grp1->y() + 2, sm_grp1->w() - 4, sm_grp1->h() - 4);
-		scaleSmeter->resize(grpMeters->x(), grpMeters->y() + 6, grpMeters->w(), scaleSmeter->h());
-		sldrRcvSignal->resize(scaleSmeter->x() + 2, scaleSmeter->y() + scaleSmeter->h() + 6, scaleSmeter->w() - 4, sldrRcvSignal->h());
-		sldrALC->resize(sldrRcvSignal->x(), sldrRcvSignal->y(), sldrRcvSignal->w(), sldrRcvSignal->h());
-		sldrIDD->resize(sldrRcvSignal->x(), sldrRcvSignal->y(), sldrRcvSignal->w(), sldrRcvSignal->h());
-		sldrSWR->resize(sldrRcvSignal->x(), sldrRcvSignal->y(), sldrRcvSignal->w(), sldrRcvSignal->h());
-		grpMeters->redraw();
-		sm_grp1->redraw();
-		sldrRcvSignal->redraw();
-		sldrALC->redraw();
-		sldrIDD->redraw();
-		sldrSWR->redraw();
-	}
-
 	if (progStatus.schema == 1 && selrig->widgets[0].W != (Fl_Widget *)0) {
 		int i = 0;
 		while (selrig->widgets[i].W != NULL) {
@@ -695,8 +677,7 @@ void TRACED(adjust_control_positions)
 	}
 	if (!selrig->has_power_out) {
 		sldrFwdPwr->deactivate();
-		sigbar_PWR->hide(); //deactivate();
-		scalePower->hide();
+		sigbar_PWR->deactivate();
 	}
 
 	switch (progStatus.UIsize) {
@@ -1323,6 +1304,9 @@ static void cb_pbt(Fl_Counter *, void *)
 
 void TRACED(init_dsp_controls)
 
+	if (xcvr_name == rig_KX3.name_ || xcvr_name == rig_K4.name_)
+		return;
+
 	if (selrig->has_dsp_controls) {
 		opDSP_lo->clear();
 		opDSP_hi->clear();
@@ -2318,12 +2302,6 @@ void cb_bw_A(Fl_ComboBox *, void *)
 	guard_lock serial(&mutex_serial);
 	selrig->set_bwA( nubw );
 	vfoA.iBW = nubw;
-//	int timeout = 500; // msec
-//	while (timeout && (selrig->get_bwA() != nubw)) {
-//		MilliSleep(50);
-//		timeout -= 50;
-//		Fl::awake();
-//	}
 }
 
 void cb_bw_B(Fl_ComboBox *, void *)
@@ -2332,18 +2310,9 @@ void cb_bw_B(Fl_ComboBox *, void *)
 	guard_lock serial(&mutex_serial);
 	selrig->set_bwB( nubw );
 	vfoB.iBW = nubw;
-//	int timeout = 500; // msec
-//	while (timeout && (selrig->get_bwB() != nubw)) {
-//		MilliSleep(50);
-//		timeout -= 50;
-//		Fl::awake();
-//	}
 }
 
 void TRACED(init_elecraft_xcvrs)
-	if (!(xcvr_name == rig_K3.name_ || 
-		  xcvr_name == rig_KX3.name_ ||
-		  xcvr_name == rig_K4.name_ ) ) return;
 
 	if (xcvr_name == rig_K3.name_) {
 		btnB->hide();
@@ -2559,8 +2528,8 @@ trace(1, "selrig->initialize()");
 
 		if (selrig->name_ == rig_QCXP.name_) read_menus();
 
-if (!testmode && xcvr_name != rig_null.name_) {
-	trace(1, "selrig->check()");
+	if (!testmode && xcvr_name != rig_null.name_ && (progStatus.xcvr_serial_port != "xml_client")) {
+		trace(1, "selrig->check()");
 		if (!selrig->check()) {
 			trace(1, "FAILED");
 			bypass_serial_thread_loop = true;
