@@ -23,7 +23,7 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
-#include <config.h>
+#include "config.h"
 
 #include <sys/types.h>
 
@@ -300,7 +300,7 @@ void Address::lookup(const char* proto_name)
 	struct addrinfo hints;
 	memset(&hints, 0, sizeof(hints));
 #  ifdef AI_ADDRCONFIG
-	hints.ai_flags = AI_ADDRCONFIG;
+	hints.ai_flags = AI_PASSIVE;
 #  endif
 	hints.ai_family = AF_UNSPEC;
 	hints.ai_socktype = (proto == IPPROTO_TCP ? SOCK_STREAM : SOCK_DGRAM);
