@@ -46,7 +46,7 @@ int current_ui_size = -1;
 status progStatus = {
 	50,			// int mainX;
 	50,			// int mainY;
-	735,		// int mainW;
+	800,		// int mainW;
 	150,		// int mainH;
 	small_ui,	// UISIZE, UIsize;
 	false,		// UIchanged;
@@ -72,8 +72,6 @@ status progStatus = {
 	0,			// int serial_post_write_delay
 	50,			// int serial_timeout;
 
-	false,		// bool serial_echo;
-
 	0,			// bool serial_catptt;
 	0,			// bool serial_rtsptt;
 	0,			// bool serial_dtrptt;
@@ -473,6 +471,10 @@ status progStatus = {
 //	"7362",		// std::string server_port
 //	"127.0.0.1",// std::string server_address
 
+	"127.0.0.1", // std::string xmlrig_addr;
+	"12345",	// std::string xmlrig_port;
+	false,		// bool	xmlrpg_rig;
+
 	"4001",		// std::string tcpip_port
 	"127.0.0.1",// std::string tcpip_address
 	50,			// int tcpip_ping_delay
@@ -664,7 +666,6 @@ void status::saveLastState()
 	spref.set("serial_timeout", serial_timeout);
 	spref.set("serloop_timing", serloop_timing);
 
-	spref.set("serial_echo", serial_echo);
 	spref.set("ptt_via_cat", serial_catptt);
 	spref.set("ptt_via_rts", serial_rtsptt);
 	spref.set("ptt_via_dtr", serial_dtrptt);
@@ -705,6 +706,7 @@ void status::saveLastState()
 	spref.set("poll_auto_notch", poll_auto_notch);
 	spref.set("poll_notch", poll_notch);
 	spref.set("poll_ifshift", poll_ifshift);
+	spref.set("poll_pbt", poll_pbt);
 	spref.set("poll_power_control", poll_power_control);
 	spref.set("poll_pre_att", poll_pre_att);
 	spref.set("poll_micgain", poll_micgain);
@@ -1089,6 +1091,9 @@ void status::saveLastState()
 //	spref.set("server_port", server_port.c_str());
 //	spref.set("server_addr", server_addr.c_str());
 
+	spref.set("xmlrig_port", xmlrig_port.c_str());
+	spref.set("xmlrig_addr", xmlrig_addr.c_str());
+
 	spref.set("tcpip_port", tcpip_port.c_str());
 	spref.set("tcpip_addr", tcpip_addr.c_str());
 	spref.set("tcpip_ping_delay", tcpip_ping_delay);
@@ -1324,7 +1329,6 @@ bool status::loadXcvrState(std::string xcvr)
 		spref.get("serloop_timing", serloop_timing, serloop_timing);
 		if (serloop_timing < 10) serloop_timing = 10; // minimum loop delay of 10 msec
 
-		if (spref.get("serial_echo", i, i)) serial_echo = i;
 		if (spref.get("ptt_via_cat", i, i)) serial_catptt = i;
 		if (spref.get("ptt_via_rts", i, i)) serial_rtsptt = i;
 		if (spref.get("ptt_via_dtr", i, i)) serial_dtrptt = i;
@@ -1376,6 +1380,7 @@ bool status::loadXcvrState(std::string xcvr)
 		spref.get("poll_notch", poll_notch, poll_notch);
 		spref.get("poll_ifshift", poll_ifshift, poll_ifshift);
 		spref.get("poll_power_control", poll_power_control, poll_power_control);
+		spref.get("poll_pbt", poll_pbt, poll_pbt);
 		spref.get("poll_pre_att", poll_pre_att, poll_pre_att);
 		spref.get("poll_micgain", poll_micgain, poll_micgain);
 		spref.get("poll_squelch", poll_squelch, poll_squelch);
@@ -1855,6 +1860,11 @@ bool status::loadXcvrState(std::string xcvr)
 //		spref.get("server_addr", defbuffer, "127.0.0.1", MAX_DEFBUFFER_SIZE);
 //		server_addr = defbuffer;
 
+		spref.get("xmlrig_port", defbuffer, "12345", MAX_DEFBUFFER_SIZE);
+		xmlrig_port = defbuffer;
+		spref.get("xmlrig_addr", defbuffer, "127.0.0.1", MAX_DEFBUFFER_SIZE);
+		xmlrig_addr = defbuffer;
+
 		spref.get("tcpip_port", defbuffer, "4001", MAX_DEFBUFFER_SIZE);
 		tcpip_port = defbuffer;
 		spref.get("tcpip_addr", defbuffer, "127.0.0.1", MAX_DEFBUFFER_SIZE);
@@ -2272,7 +2282,6 @@ std::string status::info()
 	info << "timeout            : " << serial_timeout << "\n";
 	info << "query interval:    : " << serloop_timing << "\n";
 	info << "\n";
-	info << "serial_echo          : " << serial_echo << "\n";
 	info << "ptt_via_cat        : " << serial_catptt << "\n";
 	info << "ptt_via_rts        : " << serial_rtsptt << "\n";
 	info << "ptt_via_dtr        : " << serial_dtrptt << "\n";
@@ -2301,6 +2310,7 @@ std::string status::info()
 	info << "poll_notch         : " << poll_notch << "\n";
 	info << "poll_ifshift       : " << poll_ifshift << "\n";
 	info << "poll_power_control : " << poll_power_control << "\n";
+	info << "poll_pbt           : " << poll_pbt << "\n";
 	info << "poll_pre_att       : " << poll_pre_att << "\n";
 	info << "poll_micgain       : " << poll_micgain << "\n";
 	info << "poll_squelch       : " << poll_squelch << "\n";
