@@ -33,7 +33,7 @@
 #include <assert.h>
 #include <stdio.h>
 
-#define TCI_DEBUG
+//#define TCI_DEBUG
 
 #if 0
 #include <time.h>
@@ -79,8 +79,8 @@ TCI_VALS slice_0, slice_1;
 
 void print_vals(TCI_VALS &slice)
 {
-	std::cout << "A: " << slice.A.freq << ", " << slice.A.bw << ", " << slice.A.mod << std::endl;
-	std::cout << "B: " << slice.B.freq << ", " << slice.B.bw << ", " << slice.B.mod << std::endl;
+	std::cout << "A: " << slice.A.freq << ", " << slice.A.bw << ", " << slice.A.mod << ", " << slice.A.smeter << std::endl;
+	std::cout << "B: " << slice.B.freq << ", " << slice.B.bw << ", " << slice.B.mod << ", " << slice.B.smeter << std::endl;
 	std::cout << "Volume: " << slice.vol << std::endl;
 	std::cout << "PTT: " << slice.ptt << std::endl;
 	std::cout << "Power: " << slice.pwr << std::endl;
@@ -95,20 +95,29 @@ void handle_message(const std::string & message)
 	char szstr[50];
 	std::string str;
 	std::string rx = message;
+	size_t p = 0;
 
 	for (size_t n = 0; n < rx.length(); n++)
 		rx[n] = toupper(rx[n] & 0xFF);
 
-	if (rx.find("RX_SMETER:") == 0) { // smeter reading
-		sscanf(rx.c_str(), "RX_SMETER:%d,%d,%d;", &rxnbr, &vfo, &ival);
+#ifdef TCI_DEBUG
+std::cout << "R: " << rx << std::endl;
+#endif
+
+	if ((p = rx.find("RX_SMETER:")) != std::string::npos) { // smeter reading
+		sscanf(rx.substr(p).c_str(), "RX_SMETER:%d,%d,%d;", &rxnbr, &vfo, &ival);
 		if (rxnbr == 0) {
-			if (vfo == 0) slice_0.smeter = ival;
+			if (vfo == 0) slice_0.A.smeter = ival;
+			else          slice_0.B.smeter = ival;
+		} else {
+			if (vfo == 0) slice_1.A.smeter = ival;
+			else          slice_1.B.smeter = ival;
 		}
 	}
 	else {
 		tci_trace(2, "PARSE:", rx.c_str());
-		if (rx.find("VFO:") == 0) { // vfo:0,0,7032050;
-			sscanf(rx.c_str(), "VFO:%d,%d,%d", &rxnbr, &vfo, &ival);
+		if ((p = rx.find("VFO:")) != std::string::npos) { // vfo:0,0,7032050;
+			sscanf(rx.substr(p).c_str(), "VFO:%d,%d,%d", &rxnbr, &vfo, &ival);
 			if (rxnbr == 0) {
 				if (vfo == 0) slice_0.A.freq = ival;
 				else          slice_0.B.freq = ival;
@@ -117,26 +126,28 @@ void handle_message(const std::string & message)
 				else          slice_1.B.freq = ival;
 			}
 		}
-		else if (rx.find("DDS:") == 0) { // dds:1,14070000;
-			sscanf(rx.c_str(), "DDS:%d,%d", &rxnbr, &ival);
+		else if ((p = rx.find("DDS:")) != std::string::npos) { // dds:1,14070000;
+			sscanf(rx.substr(p).c_str(), "DDS:%d,%d", &rxnbr, &ival);
 			if (rxnbr == 0) {
 				slice_0.dds = ival;
 			} else {
 				slice_1.dds = ival;
 			}
 		}
-		else if (rx.find("RX_FILTER_BAND:") == 0) { // rx_filter_band:0,-600,600;
-			sscanf(rx.c_str(), "RX_FILTER_BAND:%d,%s", &vfo, szstr);
-			if (vfo == 0) {slice_0.A.bw = szstr; }
-			else          {slice_0.B.bw = szstr; }
+		else if ((p = rx.find("RX_FILTER_BAND:")) != std::string::npos) { // rx_filter_band:0,-600,600;
+			int slice;
+			sscanf(rx.substr(p).c_str(), "RX_FILTER_BAND:%d,%s", &slice, szstr);
+			if (slice == 0) {slice_0.A.bw = slice_0.B.bw = szstr; }
+			else            {slice_1.A.bw = slice_1.B.bw = szstr; }
 		}
-		else if (rx.find("MODULATION:") == 0) { // modulation:0,cw;
-			sscanf(rx.c_str(), "MODULATION:%d,%s", &vfo, szstr);
-			if (vfo == 0) { slice_0.A.mod = szstr; }
-			else          { slice_0.B.mod = szstr; }
+		else if ((p = rx.find("MODULATION:")) != std::string::npos) { // modulation:0,cw;
+			int slice = 0;
+			sscanf(rx.substr(p).c_str(), "MODULATION:%d,%s", &slice, szstr);
+			if (slice == 0) { slice_0.A.mod = slice_0.B.mod = szstr; }
+			else            { slice_1.A.mod = slice_1.B.mod = szstr; }
 		}
-		else if (rx.find("TRX:") == 0) {
-			sscanf(rx.c_str(), "TRX:%d,%s", &rxnbr, szstr);
+		else if ((p = rx.find("TRX:")) != std::string::npos) {
+			sscanf(rx.substr(p).c_str(), "TRX:%d,%s", &rxnbr, szstr);
 			str = szstr;
 			if (rxnbr == 0) {
 				slice_0.ptt = (str == "TRUE;");
@@ -144,8 +155,8 @@ void handle_message(const std::string & message)
 				slice_1.ptt = (str == "TRUE;");
 			}
 		}
-		else if (rx.find("SPLIT_ENABLE:") == 0) { // split_enable:0,false;
-			sscanf(rx.c_str(), "SPLIT_ENABLE:%d,%s", &rxnbr, szstr);
+		else if ((p = rx.find("SPLIT_ENABLE:")) != std::string::npos) { // split_enable:0,false;
+			sscanf(rx.substr(p).c_str(), "SPLIT_ENABLE:%d,%s", &rxnbr, szstr);
 			str = szstr;
 			if (rxnbr == 0) {
 				slice_0.split = (str == "TRUE;");
@@ -153,32 +164,32 @@ void handle_message(const std::string & message)
 				slice_1.split = (str == "TRUE;");
 			}
 		}
-		else if (rx.find("VOLUME:") == 0) { // volume:-16;
-			sscanf(rx.c_str(), "VOLUME:%d", &ival);
+		else if ((p = rx.find("VOLUME:")) != std::string::npos) { // volume:-16;
+			sscanf(rx.substr(p).c_str(), "VOLUME:%d", &ival);
 			slice_0.vol = ival;
 		}
-		else if (rx.find("SQL_ENABLE:") == 0) { // sql_enable:1,false;
-			sscanf(rx.c_str(), "SQL_ENABLE:%d,%s", &rxnbr, szstr);
+		else if ((p = rx.find("SQL_ENABLE:")) != std::string::npos) { // sql_enable:1,false;
+			sscanf(rx.substr(p).c_str(), "SQL_ENABLE:%d,%s", &rxnbr, szstr);
 			str = szstr;
 			if (rxnbr == 0) {
 				slice_0.sql = (str == "TRUE;");
 			} else
 				slice_1.sql = (str == "TRUE;");
 		}
-		else if (rx.find("SQL_LEVEL:") == 0) { // sql_level:0,-79;
-			sscanf(rx.c_str(), "SQL_LEVEL:%d,%d", &rxnbr, &ival);
+		else if ((p = rx.find("SQL_LEVEL:")) != std::string::npos) { // sql_level:0,-79;
+			sscanf(rx.substr(p).c_str(), "SQL_LEVEL:%d,%d", &rxnbr, &ival);
 			if (rxnbr == 0) {
 				slice_0.sql_level = ival;
 			} else {
 				slice_1.sql_level = ival;
 			}
 		}
-		else if (rx.find("DRIVE:") == 0) { // drive:100;
-			sscanf(rx.c_str(), "DRIVE:%d", &ival);
+		else if ((p = rx.find("DRIVE:")) != std::string::npos) { // drive:100;
+			sscanf(rx.substr(p).c_str(), "DRIVE:%d", &ival);
 			slice_0.pwr = ival;
 		}
-		else if (rx.find("TUNE:") == 0) { // tune:0,false;
-			sscanf(rx.c_str(), "TUNE:%d,%s", &rxnbr, szstr);
+		else if ((p = rx.find("TUNE:")) != std::string::npos) { // tune:0,false;
+			sscanf(rx.substr(p).c_str(), "TUNE:%d,%s", &rxnbr, szstr);
 			str = szstr;
 			if (rxnbr == 0) {
 				slice_0.tune = (str == "TRUE;");
@@ -186,12 +197,12 @@ void handle_message(const std::string & message)
 				slice_1.tune = (str == "TRUE;");
 			}
 		}
-		else if (rx.find("TX_POWER:") == 0) { // tx_power:4.3;
-			sscanf(rx.c_str(), "TX_POWER:%f", &fval);
+		else if ((p = rx.find("TX_POWER:")) != std::string::npos) { // tx_power:4.3;
+			sscanf(rx.substr(p).c_str(), "TX_POWER:%f", &fval);
 			slice_0.tx_power = fval;
 		}
-		else if (rx.find("TX_SWR:") == 0) { // tx_swr:1.3;
-			sscanf(rx.c_str(), "TX_SWR:%f", &fval);
+		else if ((p = rx.find("TX_SWR:")) != std::string::npos) { // tx_swr:1.3;
+			sscanf(rx.substr(p).c_str(), "TX_SWR:%f", &fval);
 			slice_0.tx_swr = fval;
 		}
 	}
