@@ -22,6 +22,8 @@
 # pragma warning(disable:4786)    // identifier was truncated in debug info
 #endif
 
+#include "threads.h"
+
 namespace XmlRpc {
 
   //! A simple platform-independent mutex API implemented for posix and windows.
@@ -53,7 +55,7 @@ namespace XmlRpc {
   private:
 
     //! Native Mutex object
-    void* _pMutex;
+    pthread_mutex_t* _pMutex;
 
   };  // class XmlRpcMutex
 
