@@ -1,39 +1,32 @@
 // ----------------------------------------------------------------------------
-// Copyright (C) 2014
-//              David Freese, W1HKJ
 //
-// This file is part of flrig.
-//
-// flrig is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// ----------------------------------------------------------------------------
+// flxmlrpc Copyright (c) 2015 by W1HKJ, Dave Freese <iam_w1hkj@w1hkj.com>
+//    
 // XmlRpc++ Copyright (c) 2002-2008 by Chris Morley
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public
-// License as published by the Free Software Foundation; either
-// version 3 of the License, or (at your option) any later version.
-// 
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Lesser General Public License for more details.
-// 
-// You should have received a copy of the GNU Lesser General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
+// This file is part of fldigi
+//
+// flxmlrpc is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or
+// (at your option) any later version.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
+#include "config.h"
+
 #include "XmlRpcValue.h"
 #include "XmlRpcException.h"
 #include "XmlRpcUtil.h"
-#include "base64.h"
+#include "XmlRpcBase64.h"
 
 #include <iostream>
 #include <ostream>
 #include <stdlib.h>
 #include <stdio.h>
-
+#include <string.h>
 
 namespace XmlRpc {
 
@@ -163,7 +156,7 @@ namespace XmlRpc {
   // Predicate for tm equality
   static bool tmEq(struct tm const& t1, struct tm const& t2) {
     return t1.tm_sec == t2.tm_sec && t1.tm_min == t2.tm_min &&
-            t1.tm_hour == t2.tm_hour && t1.tm_mday == t1.tm_mday &&
+            t1.tm_hour == t2.tm_hour && t1.tm_mday == t2.tm_mday &&
             t1.tm_mon == t2.tm_mon && t1.tm_year == t2.tm_year;
   }
 
@@ -251,10 +244,14 @@ namespace XmlRpc {
     }
 
     // No type tag? Assume string
-    bool result = true;
+//    bool result = true;
+    bool result = false;
+
     int valueOffset = *offset;
+
     if (XmlRpcUtil::nextTagIsEnd(VALUE_TAG, valueXml, offset))
     {
+      result = true;
       return stringFromXml(valueXml, &valueOffset);
     }
     else if (XmlRpcUtil::nextTagIs(NIL_TAG, valueXml, offset, &emptyTag))
@@ -264,41 +261,46 @@ namespace XmlRpc {
     }
     else if (XmlRpcUtil::nextTagIs(BOOLEAN_TAG, valueXml, offset, &emptyTag))
     {
-      if (emptyTag)
+      if (emptyTag) {
         *this = false;
-      else
+        result = true;
+      } else
         result = boolFromXml(valueXml, offset) && 
                  XmlRpcUtil::nextTagIsEnd(BOOLEAN_TAG, valueXml, offset);
     }
     else if (XmlRpcUtil::nextTagIs(I4_TAG, valueXml, offset, &emptyTag))
     {
-      if (emptyTag)
+      if (emptyTag) {
         *this = 0;
-      else
+        result = true;
+      } else
         result = intFromXml(valueXml, offset) && 
                  XmlRpcUtil::nextTagIsEnd(I4_TAG, valueXml, offset);
     }
     else if (XmlRpcUtil::nextTagIs(INT_TAG, valueXml, offset, &emptyTag))
     {
-      if (emptyTag)
+      if (emptyTag) {
         *this = 0;
-      else
+        result = true;
+      } else
         result = intFromXml(valueXml, offset) && 
                  XmlRpcUtil::nextTagIsEnd(INT_TAG, valueXml, offset);
     }
     else if (XmlRpcUtil::nextTagIs(DOUBLE_TAG, valueXml, offset, &emptyTag))
     {
-      if (emptyTag)
+      if (emptyTag) {
         *this = 0.0;
-      else
+        result = true;
+      } else
         result = doubleFromXml(valueXml, offset) && 
                  XmlRpcUtil::nextTagIsEnd(DOUBLE_TAG, valueXml, offset);
     }
     else if (XmlRpcUtil::nextTagIs(STRING_TAG, valueXml, offset, &emptyTag))
     {
-      if (emptyTag)
+      if (emptyTag) {
         *this = "";
-      else
+        result = true;
+      } else
         result = stringFromXml(valueXml, offset) && 
                  XmlRpcUtil::nextTagIsEnd(STRING_TAG, valueXml, offset);
     }
@@ -472,22 +474,21 @@ namespace XmlRpc {
     if (sscanf(stime.c_str(),"%4d%2d%2dT%2d:%2d:%2d",&t.tm_year,&t.tm_mon,&t.tm_mday,&t.tm_hour,&t.tm_min,&t.tm_sec) != 6)
       return false;
 
-    t.tm_year -= 1900;    // 	years since 1900
-    t.tm_mon -= 1;        // 	months 0..11
     t.tm_isdst = -1;
     _type = TypeDateTime;
     _value.asTime = new struct tm(t);
     *offset += int(stime.length());
+
     return true;
   }
 
   std::string XmlRpcValue::timeToXml() const
   {
     struct tm* t = _value.asTime;
-    char buf[20];
+    char buf[50];
+    memset(buf, 0, 50);
     snprintf(buf, sizeof(buf)-1, "%04d%02d%02dT%02d:%02d:%02d", 
       1900+t->tm_year,1+t->tm_mon,t->tm_mday,t->tm_hour,t->tm_min,t->tm_sec);
-    buf[sizeof(buf)-1] = 0;
 
     return std::string("<value><dateTime.iso8601>") + buf + std::string("</dateTime.iso8601></value>");
   }
@@ -507,7 +508,7 @@ namespace XmlRpc {
 
     // convert from base64 to binary
     int iostatus = 0;
-	  base64<char> decoder;
+	  xmlrpc_base64<char> decoder;
     std::back_insert_iterator<BinaryData> ins = std::back_inserter(*(_value.asBinary));
 		decoder.get(asString.begin(), asString.end(), ins, iostatus);
 
@@ -521,9 +522,9 @@ namespace XmlRpc {
     // convert to base64
     std::vector<char> base64data;
     int iostatus = 0;
-    base64<char> encoder;
+    xmlrpc_base64<char> encoder;
     std::back_insert_iterator<std::vector<char> > ins = std::back_inserter(base64data);
-    encoder.put(_value.asBinary->begin(), _value.asBinary->end(), ins, iostatus, base64<>::crlf());
+    encoder.put(_value.asBinary->begin(), _value.asBinary->end(), ins, iostatus, xmlrpc_base64<>::crlf());
 
     // Wrap with xml
     std::string xml = "<value><base64>";
@@ -647,8 +648,8 @@ namespace XmlRpc {
         {
           int iostatus = 0;
           std::ostreambuf_iterator<char> out(os);
-          base64<char> encoder;
-          encoder.put(_value.asBinary->begin(), _value.asBinary->end(), out, iostatus, base64<>::crlf());
+          xmlrpc_base64<char> encoder;
+          encoder.put(_value.asBinary->begin(), _value.asBinary->end(), out, iostatus, xmlrpc_base64<>::crlf());
           break;
         }
       case TypeArray:
